@@ -1,22 +1,24 @@
 import click
+from tqdm import tqdm
+
+# Own imports:
 from niceplot.draw2d import draw2dplot
 from niceplot.draw1d import draw1dratio
-from niceplot.utils import *
+import niceplot.utils as utils
 from niceplot.reader import Reader
-from tqdm import tqdm
 
 @click.command()
 @click.argument('config_file')
 def niceplot(config_file: str) -> None:
     """Module to make nice looking root plots in the ATLAS Style.
-    See https://gitlab.cern.ch/jwuerzin/nice-plot for documentation.
+    See https://gitlab.cern.ch/jwuerzin/nice-plot or https://pypi.org/project/niceplotpy/ for documentation.
     """
     # Print welcome message and version number:
-    printwelcome()
+    utils.printwelcome()
     
     # Read in config file and prep corresponding dictionary with pandas.DataFrames:
     reader = Reader(config_file)   
-    paddefaults(reader, mode='reader')
+    utils.paddefaults(reader, mode='reader')
     
     dfdict = reader.prepdfdict()
 
@@ -25,7 +27,7 @@ def niceplot(config_file: str) -> None:
     # Loop over all configurations and plotting configs; Make one plot for all configs & plot configs:
     # for plot in reader.plots:
     for plot in tqdm(reader.plots, desc="Generating Plots", unit="plots"):
-        paddefaults(plot, mode='plot')
+        utils.paddefaults(plot, mode='plot')
         
         if plot.type == '2dhist':
             # Make one 2D (exclusion) Histogram for every dataframe configuration:
@@ -52,8 +54,8 @@ def niceplot(config_file: str) -> None:
                 x=plot.x,
                 range=plot.range,
                 ylab=plot.ylab,
-                denomlab=getaddinfo(reader.configurations, plot.denominator),
-                numlab=getaddinfo(reader.configurations, plot.numerator),
+                denomlab=utils.getaddinfo(reader.configurations, plot.denominator),
+                numlab=utils.getaddinfo(reader.configurations, plot.numerator),
                 nbins=plot.nbins,
                 suffix=f"{plot.denominator}_over_{plot.numerator}",
                 logy=plot.logy,
